@@ -208,7 +208,3 @@ class DistributiveSpider(Spider):
                 redis_conn.delete(settings.REDIS_KEY_QUEUE_FILTER_REQUEST)
             if not settings.PERSISTENCE_ITEM_FILTER:
                 redis_conn.delete(settings.REDIS_KEY_QUEUE_FILTER_ITEM)
-
-        # 等待程序执行
-        self.wait_spider_controller_done()
-        self.wait_item_controller_done()
